Function load_link_keys

pub async fn load_link_keys(
    socket: &mut ManagementStream,
    controller: Controller,
    keys: Vec<LinkKey>,
    debug: bool,
    event_tx: Option<Sender<Response>>,
) -> Result<()>
This command is used to feed the kernel with currently known link keys. The command does not need to be called again upon the receipt of New Link Key events since the kernel updates its list automatically.

The debug parameter is used to tell the kernel whether to accept the usage of debug keys or not. The allowed values for this parameter are 0x00 and 0x01. All other values will return an Invalid Parameters response.

Usage of the debug parameter is deprecated and has been replaced with the Set Debug Keys command. When setting the debug option via Load Link Keys command it has the same affect as setting it via Set Debug Keys and applies to all keys in the system.