pub struct ControllerInfoExt {
pub address: Address,
pub bluetooth_version: u8,
pub manufacturer: u16,
pub supported_settings: ControllerSettings,
pub current_settings: ControllerSettings,
pub eir_data: Bytes,
}Fields
address: Addressbluetooth_version: u8manufacturer: u16supported_settings: ControllerSettingscurrent_settings: ControllerSettingseir_data: BytesContains information about class of device, local name and other values. Not all of them might be present. For example a Low Energy only device does not contain class of device information.
When any of the values in the eir_data field changes, the event
Extended Controller Information Changed will be used to inform
clients about the updated information.